#!/bin/sh

set_env() {
    set -evx
    cdir=$(dirname "$0")
    cd "$cdir"/..
    idir=debian/update
    mkdir -p "$idir"
}

error() {
    echo "Error: $*"
    exit 1
}

parse_profiles() {
    echo "DEB_BUILD_PROFILES = $DEB_BUILD_PROFILES"
    case " $DEB_BUILD_PROFILES " in
        *' astrase '*)
          D_EDITION=SE
          ;;
        *)
          D_EDITION=CE
    esac

    test -n "$ARCH" || ARCH=$(dpkg --print-architecture)
    case "$ARCH" in
        armhf|arm64)
          D_CODENAME=novorossiysk
          D_CALLBACK=nov_${ARCH}_${D_EDITION}
          ;;
        e2k-8c)
          test "$D_EDITION" = SE
          D_CODENAME=leningrad
          ;;
        amd64)
          if test "$D_EDITION" = SE
          then
            D_CODENAME=smolensk
          else
            D_CODENAME=orel
          fi  
          ;;
        *)
          error "Unsupported ARCH $ARCH"
          ;;
    esac

    if test -n "$EDITION"
    then
        test "$EDITION" = "$D_EDITION"
    else
        EDITION="$D_EDITION"
    fi
    if test -n "$CODENAME"
    then
        test "$CODENAME" = "$D_CODENAME"
    else
        CODENAME="$D_CODENAME"
    fi
    CODENAME_BIG=$(echo $CODENAME | sed -e 's/^./\U&/')

    test -n "$D_CALLBACK" || D_CALLBACK="$D_CODENAME"
    case " $DEB_BUILD_PROFILES " in
        *' astrabuster '*)
          set_version_${D_CALLBACK}_buster
          ;;
        *)
          set_version_${D_CALLBACK}_stretch
          ;;
    esac
}

set_version_smolensk_buster() {
    set_2_version 1.7
}

set_version_smolensk_stretch() {
    set_2_version 1.6
}

set_version_leningrad_stretch() {
    set_2_version 8.1
}

set_version_nov_arm64_CE_buster() {
    set_3_version 4.11
}

set_version_nov_arm64_SE_buster() {
    set_3_version 4.1
}

set_version_nov_armhf_CE_buster() {
    set_3_version 4.10
}

set_version_nov_armhf_SE_buster() {
    set_3_version 4.1
}

set_version_orel_buster() {
    set_3_version 2.13
}

set_version_orel_stretch() {
    set_3_version 2.12
}

set_2_version() {
    if test -n "$VERSION"
    then
        test "$VERSION" = "$D_VERSION"
    else
        VERSION="$1"
    fi
}

get_minor_version() {
    cut -d'.' -f3 | sed 's/-+.*//'
}

set_3_version() {
    local prefix
    prefix="$1"

    test -n "$VERSION" ||
        VERSION=$(cut -d' ' -f2 /etc/astra_version)

    case "$VERSION" in
        "$prefix".*)
          ;;
        *)
          error "Incorrect VERSION $VERSION"
    esac
}

update_pkg_version() {
    local u_version

    if test "$EDITION" = SE
    then
        cp src/astra_update_version_"$CODENAME" "$idir"/astra_update_version
        u_version=u$(awk '/^Update / { print $2 }' "$idir"/astra_update_version)
    else
        u_version=
    fi
    PKG_VERSION=${PKG_VERSION:-v"$VERSION$u_version"}

    local old_version
    old_version=$(dpkg-parsechangelog -S Version)
    local prefix
    prefix=$(echo "$old_version" | sed -e 's/\+v.*//')
    local new_version
    new_version="$prefix"+"$PKG_VERSION"

    test "$old_version" != "$new_version" || return 0
    dch --preserve -D unstable -M -u low -v "$new_version" Update version
}

create_astra_version() {
    echo "$EDITION $VERSION ($CODENAME)" >"$idir"/astra_version
}

create_lsb_release() {
    cat <<EOF >"$idir"/lsb-release
DISTRIB_ID="AstraLinux${EDITION}"
DISTRIB_DESCRIPTION="Astra Linux $EDITION $VERSION ($CODENAME_BIG)"
DISTRIB_RELEASE=$VERSION
DISTRIB_CODENAME=$CODENAME
EOF
}

create_os_release() {
    cat <<EOF >"$idir"/os-release
PRETTY_NAME="Astra Linux ($CODENAME_BIG $VERSION)"
NAME="Astra Linux ($CODENAME_BIG)"
ID=astra
ID_LIKE=debian
ANSI_COLOR="1;31"
HOME_URL="http://astralinux.ru"
SUPPORT_URL="http://astralinux.ru/support"
VARIANT_ID=$CODENAME
VARIANT=$CODENAME_BIG
LOGO=astra
VERSION_ID=$VERSION
EOF
}

create_issues() {
    VER=$(cat "$idir"/astra_version)
    echo "Astra Linux $VER \\n \\l" >"$idir"/issue
    echo "Astra Linux $VER" >"$idir"/issue.net
}

set_env
parse_profiles
update_pkg_version
create_astra_version
create_lsb_release
create_os_release
create_issues

